==> mgb-0.6.8.tar.bz2: language/lang_schweizerdeutsch_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ====================================== //
	// lang_import.php - Schweizerdeutsch 1.3 //
	// ====================================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// header
	$lang['h_title'] = "Import der Daten einer &auml;lteren Version";

	// general
	$lang['next_step'] = "&raquo; Weiter &raquo;";
	$lang['yes'] = "Ja";
	$lang['no'] = "Nein";
	$lang['active'] = "Aktiv";
	$lang['inactive'] = "Inaktiv";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fehlgeschlagen!";

	// installation
	$lang['title'] = "Import der Daten einer &auml;lteren Version";

	$lang['expl_import'] = "Bitte geben Sie die Verbindungsdaten der Datenbank an, in der sich die Installation Ihres alten MGB G&auml;stebuches befindet. Zus&auml;tzlich m&uuml;ssen sie den absoluten Pfad zu Ihrer alten Installation <b>ohne den Domainnamen</b> angeben. z.B.: Anstatt <i>http://www.beispiel.de/php/mgb/</i> nur <i>/php/mgb/</i>. Beachten Sie dabei die Schr&auml;gstriche am Anfang und am Ende.";

	// step 1
	$lang['db_title'] = "Datenbankinformationen:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Datenbankname:";
	$lang['db_username'] = "Benutzername:";
	$lang['db_password'] = "Passwort:";
	$lang['oldgb_path'] = "Pfad:";
	$lang['import_settings'] = "Einstellungen importieren:";
	
	// errormessages step 1
	$lang['no_error'] = "Alle angegebenen Werte sind OK!";
	$lang['error_1_step1'] = "Bitte f&uuml;llen Sie alle Felder aus!";
	$lang['error_2_step1'] = "Die Verbindung zur Datenbank ist fehlgeschlagen, &uuml;berpr&uuml;fen Sie ihre Zugangsdaten.";
	$lang['error_3_step1'] = "In dem von Ihnen angegebenen Pfad konnte keine MGB Installation gefunden werden.";
	$lang['error_4_step1'] = "Die von Ihnen angegebene Datenbank ist OK, aber es konnte keine fr&uuml;here Installation darin gefunden werden.";
	
	// step 2
	$lang['transfer_settings'] = "&uuml;bertrage Einstellungen...";
	$lang['transfer_entries'] = "&uuml;bertrage Eintr&auml;ge...";
	
	// finish
	$lang['import_finish'] = "Herzlichen Gl&uuml;ckwunsch!<br><br>Die Daten Ihrer alten MGB Installation wurden erfolgreich in das MGB ".MGB_VERSION." &uuml;bertragen.<br><br><a href='../admin/admin.php' title='Zur Administration'>Zur Administration</a><br><a href='../index.php' title='Zum G&auml;stebuch'>Zum G&auml;stebuch</a>";
?>

==> mgb-0.6.9.1.tar.bz2: language/lang_schweizerdeutsch_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ================================== //
	// lang_import.php - German (Sie) 1.5 //
	// ================================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// header
	$lang['h_title'] = "Import der Daten einer &auml;lteren Version";

	// general
	$lang['next_step'] = "&raquo; Weiter &raquo;";
	$lang['yes'] = "Ja";
	$lang['no'] = "Nein";
	$lang['active'] = "Aktiv";
	$lang['inactive'] = "Inaktiv";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fehlgeschlagen!";

	// installation
	$lang['title'] = "Import der Daten einer &auml;lteren Version (NUR 0.5.x)";

	$lang['expl_import'] = "Bitte geben Sie die Verbindungsdaten der Datenbank an, in der sich die Installation Ihres alten MGB G&auml;stebuches (0.5.x) befindet. Zus&auml;tzlich m&uuml;ssen sie den absoluten Pfad zu Ihrer alten Installation <b>ohne den Domainnamen</b> angeben. z.B.: Anstatt <i>http://www.beispiel.de/php/mgb/</i> nur <i>/php/mgb/</i>. Beachten Sie dabei die Schr&auml;gstriche am Anfang und am Ende.";

	// step 1
	$lang['db_title'] = "Datenbankinformationen:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Datenbankname:";
	$lang['db_username'] = "Benutzername:";
	$lang['db_password'] = "Passwort:";
	$lang['oldgb_path'] = "Pfad:";
	$lang['import_settings'] = "Einstellungen importieren:";

	// errormessages step 1
	$lang['no_error'] = "Alle angegebenen Werte sind OK!";
	$lang['error_1_step1'] = "Bitte f&uuml;llen Sie alle Felder aus!";
	$lang['error_2_step1'] = "Die Verbindung zur Datenbank ist fehlgeschlagen, &uuml;berpr&uuml;fen Sie ihre Zugangsdaten.";
	$lang['error_3_step1'] = "In dem von Ihnen angegebenen Pfad konnte keine 0.5.x MGB Installation gefunden werden.";
	$lang['error_4_step1'] = "Die von Ihnen angegebene Datenbank ist OK, aber es konnte keine 0.5.x Installation darin gefunden werden.";

	// step 2
	$lang['transfer_settings'] = "&uuml;bertrage Einstellungen...";
	$lang['transfer_entries'] = "&uuml;bertrage Eintr&auml;ge...";

	// finish
	$lang['import_finish'] = "Herzlichen Gl&uuml;ckwunsch!<br><br>Die Daten Ihrer alten MGB Installation wurden erfolgreich in das MGB ".MGB_VERSION." &uuml;bertragen.<br><br><a href='../admin/admin.php' title='Zur Administration'>Zur Administration</a><br><a href='../index.php' title='Zum G&auml;stebuch'>Zum G&auml;stebuch</a>";
?>
